@@ -27,8 +27,13 @@ Printout handling module
 
 """
 
+import i18n
+
 import wx
 
+#use ugettext instead of getttext to avoid unicode errors
+_ = i18n.language.ugettext
+
 
 class PrintCanvas(wx.ScrolledWindow):
     """Canvas for print and print preview"""
@@ -191,8 +196,6 @@ class Printout(wx.Printout):
         #-------------------------------------------
 
         self.canvas.DoDrawing(dc)
-        dc.DrawText("Page: %d" % page, marginX/2, maxY-marginY)
-
-        return True
-
+        dc.DrawText(_("Page: {}").format(page), marginX/2, maxY-marginY)
 
+        return True
\ No newline at end of file
